Theme Plugin | vdoc 0.19.0 documentation

Skip to content

# Theme Plugin

vdoc can be extended with a theme plugin.

Note

`<MODE>` can be either `DARK` or `LIGHT`.

The following settings are available:

Table 3 Theme Plugin Environment Variables
Environment variable | Explanation | Default | Example
--- | --- | --- | ---
`VDOC_PLUGINS_THEME_<MODE>__LOGO_URL` | The URL of the logo to be used in the frontend. | `https://logos.vorausrobotik.com/v_rgb.png` | `https://example.com/logo.png`
`VDOC_PLUGINS_THEME_<MODE>__LOGO_URL_SMALL` | The URL of the small logo to be used in the frontend. | `https://logos.vorausrobotik.com/v_rgb.png` | `https://example.com/logo.png`

Footer Plugin
Development